@@ -81,7 +81,12 @@ def date_and_delta(value, *, now=None):
     return date, abs_timedelta(delta)
 
 
-def naturaldelta(value, months=True, minimum_unit="seconds"):
+def naturaldelta(
+    value,
+    months=True,
+    minimum_unit="seconds",
+    when=None,
+) -> str:
     """Return a natural representation of a timedelta or number of seconds.
 
     This is similar to `naturaltime`, but does not add tense to the result.
@@ -91,16 +96,30 @@ def naturaldelta(value, months=True, minimum_unit="seconds"):
         months (bool): If `True`, then a number of months (based on 30.5 days) will be
             used for fuzziness between years.
         minimum_unit (str): The lowest unit that can be used.
+        when (datetime.timedelta): Point in time relative to which _value_ is
+            interpreted.  Defaults to the current time in the local timezone.
 
     Returns:
         str: A natural representation of the amount of time elapsed.
+
+    Examples
+        Compare two timestamps in a custom local timezone::
+
+        import datetime as dt
+        from dateutil.tz import gettz
+
+        berlin = gettz("Europe/Berlin")
+        now = dt.datetime.now(tz=berlin)
+        later = now + dt.timedelta(minutes=30)
+
+        assert naturaldelta(later, when=now) == "30 minutes"
     """
     tmp = Unit[minimum_unit.upper()]
     if tmp not in (Unit.SECONDS, Unit.MILLISECONDS, Unit.MICROSECONDS):
         raise ValueError(f"Minimum unit '{minimum_unit}' not supported")
     minimum_unit = tmp
 
-    date, delta = date_and_delta(value)
+    date, delta = date_and_delta(value, now=when)
     if date is None:
         return value
 
@@ -173,7 +192,13 @@ def naturaldelta(value, months=True, minimum_unit="seconds"):
         return ngettext("%d year", "%d years", years) % years
 
 
-def naturaltime(value, future=False, months=True, minimum_unit="seconds"):
+def naturaltime(
+    value,
+    future=False,
+    months=True,
+    minimum_unit="seconds",
+    when=None,
+) -> str:
     """Return a natural representation of a time in a resolution that makes sense.
 
     This is more or less compatible with Django's `naturaltime` filter.
@@ -186,11 +211,13 @@ def naturaltime(value, future=False, months=True, minimum_unit="seconds"):
         months (bool): If `True`, then a number of months (based on 30.5 days) will be
             used for fuzziness between years.
         minimum_unit (str): The lowest unit that can be used.
+        when (datetime.datetime): Point in time relative to which _value_ is
+            interpreted.  Defaults to the current time in the local timezone.
 
     Returns:
         str: A natural representation of the input in a resolution that makes sense.
     """
-    now = _now()
+    now = when or _now()
     date, delta = date_and_delta(value, now=now)
     if date is None:
         return value
@@ -199,7 +226,7 @@ def naturaltime(value, future=False, months=True, minimum_unit="seconds"):
         future = date > now
 
     ago = _("%s from now") if future else _("%s ago")
-    delta = naturaldelta(delta, months, minimum_unit)
+    delta = naturaldelta(delta, months, minimum_unit, when=when)
 
     if delta == _("a moment"):
         return _("now")
@@ -207,12 +234,13 @@ def naturaltime(value, future=False, months=True, minimum_unit="seconds"):
     return ago % delta
 
 
-def naturalday(value, format="%b %d"):
+def naturalday(value, format="%b %d") -> str:
     """Return a natural day.
 
     For date values that are tomorrow, today or yesterday compared to
     present day return representing string. Otherwise, return a string
     formatted according to `format`.
+
     """
     try:
         value = dt.date(value.year, value.month, value.day)
@@ -232,7 +260,7 @@ def naturalday(value, format="%b %d"):
     return value.strftime(format)
 
 
-def naturaldate(value):
+def naturaldate(value) -> str:
     """Like `naturalday`, but append a year for dates more than ~five months away."""
     try:
         value = dt.date(value.year, value.month, value.day)
@@ -318,17 +346,17 @@ def _suitable_minimum_unit(min_unit, suppress):
     If not suppressed, return the same unit:
 
     >>> from humanize.time import _suitable_minimum_unit, Unit
-    >>> _suitable_minimum_unit(Unit.HOURS, [])
-    <Unit.HOURS: 4>
+    >>> _suitable_minimum_unit(Unit.HOURS, []).name
+    'HOURS'
 
     But if suppressed, find a unit greather than the original one that is not
     suppressed:
 
-    >>> _suitable_minimum_unit(Unit.HOURS, [Unit.HOURS])
-    <Unit.DAYS: 5>
+    >>> _suitable_minimum_unit(Unit.HOURS, [Unit.HOURS]).name
+    'DAYS'
 
-    >>> _suitable_minimum_unit(Unit.HOURS, [Unit.HOURS, Unit.DAYS])
-    <Unit.MONTHS: 6>
+    >>> _suitable_minimum_unit(Unit.HOURS, [Unit.HOURS, Unit.DAYS]).name
+    'MONTHS'
     """
     if min_unit in suppress:
         for unit in Unit:
@@ -346,8 +374,8 @@ def _suppress_lower_units(min_unit, suppress):
     """Extend suppressed units (if any) with all units lower than the minimum unit.
 
     >>> from humanize.time import _suppress_lower_units, Unit
-    >>> list(sorted(_suppress_lower_units(Unit.SECONDS, [Unit.DAYS])))
-    [<Unit.MICROSECONDS: 0>, <Unit.MILLISECONDS: 1>, <Unit.DAYS: 5>]
+    >>> [x.name for x in sorted(_suppress_lower_units(Unit.SECONDS, [Unit.DAYS]))]
+    ['MICROSECONDS', 'MILLISECONDS', 'DAYS']
     """
     suppress = set(suppress)
     for u in Unit:
@@ -358,7 +386,7 @@ def _suppress_lower_units(min_unit, suppress):
     return suppress
 
 
-def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f"):
+def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f") -> str:
     """Return a precise representation of a timedelta.
 
     ```pycon
@@ -368,6 +396,7 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f"):
     >>> delta = dt.timedelta(seconds=3633, days=2, microseconds=123000)
     >>> precisedelta(delta)
     '2 days, 1 hour and 33.12 seconds'
+
     ```
 
     A custom `format` can be specified to control how the fractional part
@@ -376,6 +405,7 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f"):
     ```pycon
     >>> precisedelta(delta, format="%0.4f")
     '2 days, 1 hour and 33.1230 seconds'
+
     ```
 
     Instead, the `minimum_unit` can be changed to have a better resolution;
@@ -387,6 +417,7 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f"):
     ```pycon
     >>> precisedelta(delta, minimum_unit="microseconds")
     '2 days, 1 hour, 33 seconds and 123 milliseconds'
+
     ```
 
     If desired, some units can be suppressed: you will not see them represented and the
@@ -395,6 +426,7 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f"):
     ```pycon
     >>> precisedelta(delta, suppress=['days'])
     '49 hours and 33.12 seconds'
+
     ```
 
     Note that microseconds precision is lost if the seconds and all
@@ -404,6 +436,21 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f"):
     >>> delta = dt.timedelta(seconds=90, microseconds=100)
     >>> precisedelta(delta, suppress=['seconds', 'milliseconds', 'microseconds'])
     '1.50 minutes'
+
+    ```
+
+    If the delta is too small to be represented with the minimum unit,
+    a value of zero will be returned:
+
+    ```pycon
+    >>> delta = dt.timedelta(seconds=1)
+    >>> precisedelta(delta, minimum_unit="minutes")
+    '0.02 minutes'
+
+    >>> delta = dt.timedelta(seconds=0.1)
+    >>> precisedelta(delta, minimum_unit="minutes")
+    '0 minutes'
+
     ```
     """
     date, delta = date_and_delta(value)
@@ -479,7 +526,7 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f"):
     texts = []
     for unit, fmt in zip(reversed(Unit), fmts):
         singular_txt, plural_txt, value = fmt
-        if value > 0:
+        if value > 0 or (not texts and unit == min_unit):
             fmt_txt = ngettext(singular_txt, plural_txt, value)
             if unit == min_unit and math.modf(value)[0] > 0:
                 fmt_txt = fmt_txt.replace("%d", format)
